import React from 'react';
import { Route, Redirect, RouteProps } from 'react-router-dom';
import { NonAuthRoutes } from 'components/api/routes';

/**
 * A wrapper for <Route> that redirects to the login screen if you're not yet authenticated.
 * */

type Props = {
  Component: React.FC<RouteProps>;
  path: string;
  requiredRoles: string[];
};

/* eslint-disable react/jsx-props-no-spreading */
export const PrivateRoute = ({
  Component,
  path,
  requiredRoles,
}: Props): JSX.Element => {
  const isAuthed = false;
  const userHasRequiredRole = requiredRoles.includes('admin');

  const message = userHasRequiredRole
    ? 'Please log in to view this page'
    : 'Your role is not allowed';
  return (
    <Route
      exact={false}
      path={path}
      render={(props: RouteProps) =>
        isAuthed ? (
          <Component {...props} />
        ) : (
          <Redirect
            to={{
              pathname: userHasRequiredRole
                ? NonAuthRoutes.signIn
                : NonAuthRoutes.unauthorized,
              state: {
                message,
                requestedPath: path,
              },
            }}
          />
        )
      }
    />
  );
};
